pub struct StartSession<'a> { /* private fields */ }Expand description
Starts a new ClientSession. Construct with Client::start_session.
Implementations
Sourceimpl StartSession<'_>
impl StartSession<'_>
Sourcepub fn with_options(self, value: impl Into<Option<SessionOptions>>) -> Self
pub fn with_options(self, value: impl Into<Option<SessionOptions>>) -> Self
Set all options. Note that this will replace all previous values set.
Sourcepub fn default_transaction_options(self, value: TransactionOptions) -> Self
pub fn default_transaction_options(self, value: TransactionOptions) -> Self
The default options to use for transactions started on this session.
If these options are not specified, they will be inherited from the
Client associated with this session. They will not
be inherited from the options specified
on the Database or Collection
associated with the operations within the transaction.
Sourcepub fn causal_consistency(self, value: bool) -> Self
pub fn causal_consistency(self, value: bool) -> Self
If true, all operations performed in the context of this session will be causally consistent.
Defaults to true if SessionOptions::snapshot is unspecified.
Sourcepub fn snapshot(self, value: bool) -> Self
pub fn snapshot(self, value: bool) -> Self
If true, all read operations performed using this client session will share the same snapshot. Defaults to false.
Sourcepub fn snapshot_time(self, value: Timestamp) -> Self
pub fn snapshot_time(self, value: Timestamp) -> Self
The snapshot time to use for a snapshot session. This option can only be set if snapshot
is set to true.
Sourceimpl<'a> StartSession<'a>
impl<'a> StartSession<'a>
Sourcepub fn run(self) -> Result<ClientSession>
Available on crate feature sync only.
pub fn run(self) -> Result<ClientSession>
sync only.Synchronously execute this action.